Argument

Enum Argument 

pub enum Argument<'a, Id> {
    Int(i32),
    Uint(u32),
    Fixed(i32),
    Str(Option<Box<CString>>),
    Object(&'a Id),
    NewId(&'a Id),
    Array(Box<&'a [u8]>),
    Fd(BorrowedFd<'a>),
}
Enum of possible argument of the protocol

Variants



Int(i32)

An integer argument. Represented by a i32.



Uint(u32)

An unsigned integer argument. Represented by a u32.



Fixed(i32)

A signed fixed point number with 1/256 precision



Str(Option<Box<CString>>)

CString

The value is boxed to reduce the stack size of Argument. The performance impact is negligible as string arguments are pretty rare in the protocol.



Object(&'a Id)

Id of a wayland object



NewId(&'a Id)

Id of a newly created wayland object



Array(Box<&'a [u8]>)

Vec<u8>

The value is boxed to reduce the stack size of Argument. The performance impact is negligible as array arguments are pretty rare in the protocol.



Fd(BorrowedFd<'a>)

A file descriptor argument. Represented by a BorrowedFd.

Implementations

Source

impl<'a, Id> Argument<'a, Id>

pub fn get_type(&self) -> ArgumentType

Retrieve the type of a given argument instance