pub struct Message<'a, Id> {
pub sender_id: &'a Id,
pub opcode: u16,
pub args: SmallVec<[Argument<'a, Id>; 4]>,
}Expand description
Represents a message that has been sent from some object.
Fields
sender_id: &'a IdThe id of the object that sent the message.
opcode: u16The opcode of the message.
args: SmallVec<[Argument<'a, Id>; 4]>The arguments of the message.