OwnedMessage

Struct OwnedMessage 

pub struct OwnedMessage<Id> {
    pub sender_id: Id,
    pub opcode: u16,
    pub args: SmallVec<[OwnedArgument<Id>; 4]>,
}
Represents a message that has been sent from some object.

Fields

sender_id: Id

The id of the object that sent the message.

opcode: u16

The opcode of the message.

args: SmallVec<[OwnedArgument<Id>; 4]>

The arguments of the message.